Informix — SQLAlchemy 0.6.1 Documentation

# SQLAlchemy 0.6.1 Documentation

Search:
Version: 0.6.1 Last Updated: 05/31/2010 14:48:10
API Reference | Index
(view source)
Table of Contents » API Reference » sqlalchemy.dialects » Informix
Previous: Microsoft Access Next: MaxDB

## Informix

Support for the Informix database.

This dialect is not tested on SQLAlchemy 0.6.

Previous: Microsoft Access Next: MaxDB
© Copyright 2007, 2008, 2009, 2010, the SQLAlchemy authors and contributors. Created using Sphinx 0.6.5.